Cloudmesh Sys
=============

Cloudmesh sys is a command that allows the generation of new plugin 
commands to cmd5. For more details we like you to look at the 
`cloudmesh.cmd5` manual and the `cloudmesh.manual` pages at 

* <https://github.com/cloudmesh/cloudmesh.cmd5>
* <https://cloudmesh.github.io/cloudmesh-manual>


